Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(119)

Unified Diff: ash/system/network/network_icon.cc

Issue 2913103002: Add Tether to Mobile NetworkTypePattern. (Closed)
Patch Set: Add Tether to Mobile NetworkTypePattern. Created 3 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ash/system/network/network_icon.h ('k') | ash/system/network/network_list.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ash/system/network/network_icon.cc
diff --git a/ash/system/network/network_icon.cc b/ash/system/network/network_icon.cc
index 1174c006d687a4ae97b67238cf40d959791da5e5..ec6cb5ceeae230df58ab08e4dbe4b93b5c9a91fe 100644
--- a/ash/system/network/network_icon.cc
+++ b/ash/system/network/network_icon.cc
@@ -878,13 +878,15 @@ base::string16 GetLabelForNetwork(const chromeos::NetworkState* network,
}
}
-int GetCellularUninitializedMsg() {
+int GetMobileUninitializedMsg() {
static base::Time s_uninitialized_state_time;
static int s_uninitialized_msg(0);
NetworkStateHandler* handler = NetworkHandler::Get()->network_state_handler();
if (handler->GetTechnologyState(NetworkTypePattern::Mobile()) ==
NetworkStateHandler::TECHNOLOGY_UNINITIALIZED) {
+ // TODO (lesliewatkins): Add a more descriptive message (e.g. "Enable
+ // Bluetooth") for Tether technology type.
s_uninitialized_msg = IDS_ASH_STATUS_TRAY_INITIALIZING_CELLULAR;
s_uninitialized_state_time = base::Time::Now();
return s_uninitialized_msg;
@@ -894,7 +896,7 @@ int GetCellularUninitializedMsg() {
return s_uninitialized_msg;
}
// There can be a delay between leaving the Initializing state and when
// a Cellular device shows up, so keep showing the initializing
// animation for a bit to avoid flashing the disconnect icon.
const int kInitializingDelaySeconds = 1;
base::TimeDelta dtime = base::Time::Now() - s_uninitialized_state_time;
@@ -950,8 +952,8 @@ void GetDefaultNetworkImageAndLabel(IconType icon_type,
}
}
if (!network) {
- // If no connecting network, check for cellular initializing.
- int uninitialized_msg = GetCellularUninitializedMsg();
+ // If no connecting network, check for mobile initializing.
+ int uninitialized_msg = GetMobileUninitializedMsg();
if (uninitialized_msg != 0) {
*image = GetConnectingImage(icon_type, shill::kTypeCellular);
if (label)
@@ -894,7 +896,7 @@ int GetCellularUninitializedMsg() {
}
// There can be a delay between leaving the Initializing state and when
- // a Cellular device shows up, so keep showing the initializing
+ // a Mobile device shows up, so keep showing the initializing
// animation for a bit to avoid flashing the disconnect icon.
const int kInitializingDelaySeconds = 1;
« no previous file with comments | « ash/system/network/network_icon.h ('k') | ash/system/network/network_list.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698